"""

Configs migration



Generation datetime: 2021-03-16 08:28:55.205793

"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "27a016ed"

DOWN_REVISION = "31045054"

limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_MATCHER_CLUSTERS",
        oldValidationSchema={
            "type": "array",
            "description": "luna matcher clusters",
            "items": {
                "type": "object",
                "description": "core matcher cluster",
                "properties": {
                    "routing_key": {"type": "string"},
                    "rabbit_exchange": {"type": "string"},
                    "cluster_type": {
                        "type": "string",
                        "enum": ["core-matcher", "core-indexed-matcher"],
                    },
                },
                "required": ["routing_key", "cluster_type"],
                "additionalProperties": False,
                "default": {
                    "cluster_type": "python-matcher",
                    "routing_key": "matcher",
                    "rabbit_exchange": "luna.match",
                },
            },
            "minItems": 0,
        },
        newValidationSchema={
            "type": "array",
            "description": "luna matcher clusters",
            "items": {
                "type": "object",
                "description": "core matcher cluster",
                "properties": {
                    "routing_key": {"type": "string"},
                    "rabbit_exchange": {"type": "string"},
                    "cluster_type": {
                        "type": "string",
                        "enum": ["core-indexed-matcher"],
                    },
                },
                "required": ["routing_key", "cluster_type"],
                "additionalProperties": False,
                "default": {
                    "cluster_type": "python-matcher",
                    "routing_key": "matcher",
                    "rabbit_exchange": "luna.match",
                },
            },
            "minItems": 0,
        },
        oldDefaultValue=[
            {
                "cluster_type": "core-matcher",
                "routing_key": "matcher",
                "rabbit_exchange": "luna.match",
            }
        ],
        newDefaultValue=[
            {
                "cluster_type": "core-indexed-matcher",
                "routing_key": "matcher",
                "rabbit_exchange": "luna.match",
            }
        ],
        settingUpgradeFunction=lambda clusters: [
            cluster for cluster in clusters if cluster["cluster_type"] != "core-matcher"
        ],
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-matcher-proxy"],
        newServices=["luna-matcher-proxy"],
    ),
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "matcher": {"type": "boolean"},
                "indexed_matcher": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "liveness": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "matcher",
                "indexed_matcher",
                "luna_matcher_proxy",
                "liveness",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "indexed_matcher": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "liveness": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "indexed_matcher",
                "luna_matcher_proxy",
                "liveness",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "matcher": True,
            "indexed_matcher": False,
            "luna_matcher_proxy": False,
            "liveness": False,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "indexed_matcher": False,
            "luna_matcher_proxy": False,
            "liveness": False,
        },
        settingUpgradeFunction=lambda services: {
            service: value for service, value in services.items() if service != "matcher"
        },
        settingDowngradeFunction=lambda services: (services.setdefault("matcher", False) or services),
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="QUEUE_SETTINGS",
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-index-manager",
            "luna-indexed-matcher",
            "luna-indexer",
            "luna-matcher",
            "luna-matcher-proxy",
        ],
        newServices=[
            "luna-admin",
            "luna-index-manager",
            "luna-indexed-matcher",
            "luna-indexer",
            "luna-matcher-proxy",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_ADDRESS",
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-index-manager",
            "luna-indexed-matcher",
            "luna-indexer",
            "luna-licenses",
            "luna-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-index-manager",
            "luna-indexed-matcher",
            "luna-indexer",
            "luna-licenses",
            "luna-tasks",
        ],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to remove

    mh.removeLimitation(limitationName="EVENTS_DATABASE")

    mh.removeLimitation(limitationName="MATCHER_FACES_CLIENT_PROPERTIES")

    mh.removeLimitation(limitationName="MATCHER_FSDK")

    mh.removeLimitation(limitationName="MATCHER_QUEUE")

    mh.removeLimitation(limitationName="MATCHER_WORKER_AND_MESSAGE")

    mh.removeLimitation(limitationName="MATCHING")

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to add

    mh.addLimitation(
        limitationName="EVENTS_DATABASE",
        validationSchema={
            "type": "object",
            "properties": {
                "database": {
                    "type": "object",
                    "properties": {
                        "driver": {"type": "string"},
                        "config": {
                            "type": "object",
                            "properties": {
                                "dbName": {"type": "string"},
                                "host": {"type": "string"},
                                "port": {"type": "integer"},
                                "user": {"type": "string"},
                                "password": {"type": "string"},
                                "friendTag": {"type": "string"},
                                "strangerTag": {"type": "string"},
                                "eventDataToSkip": {
                                    "type": "array",
                                    "items": {"type": "string", "enum": ["location"]},
                                },
                                "eventDataOptional": {
                                    "type": "array",
                                    "items": {
                                        "type": "string",
                                        "enum": ["is_friend", "age", "sex"],
                                    },
                                },
                            },
                        },
                    },
                    "required": ["driver"],
                    "additionalProperties": False,
                }
            },
            "description": "Events database settings.",
            "additionalProperties": False,
        },
        defaultValue={
            "database": {
                "driver": "dbpostgresdrv",
                "config": {
                    "dbName": "luna_events",
                    "host": "127.0.0.1",
                    "user": "luna",
                    "port": 5432,
                    "friendTag": "1",
                    "strangerTag": "0",
                    "eventDataToSkip": ["location"],
                },
            }
        },
        description="Events matcher settings.",
        services=["luna-indexed-matcher", "luna-matcher"],
        groupNames=["luna-platform"],
    )

    mh.addLimitation(
        limitationName="MATCHER_FACES_CLIENT_PROPERTIES",
        validationSchema={
            "type": "object",
            "properties": {
                "httpClient": {
                    "type": "object",
                    "properties": {
                        "requestTimeoutMs": {"type": "integer"},
                        "connectTimeoutMs": {"type": "integer"},
                    },
                    "description": "Timeouts settings.",
                }
            },
        },
        defaultValue={"httpClient": {"requestTimeoutMs": 5000, "connectTimeoutMs": 2000}},
        description="Matcher faces client properties.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )

    mh.addLimitation(
        limitationName="MATCHER_FSDK",
        validationSchema={
            "type": "object",
            "properties": {
                "fsdk": {
                    "type": "object",
                    "properties": {
                        "configPath": {"type": "string"},
                        "runtimeConfigPath": {"type": "string"},
                        "dataPath": {"type": "string"},
                    },
                    "description": "Paths to fsdk config and data.",
                }
            },
        },
        defaultValue={
            "fsdk": {
                "configPath": "/srv/luna/conf/faceengine.conf",
                "runtimeConfigPath": "/srv/luna/conf/runtime.conf",
                "dataPath": "/srv/luna/data",
            }
        },
        description="Matcher fsdk settings.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )

    mh.addLimitation(
        limitationName="MATCHER_QUEUE",
        validationSchema={
            "type": "object",
            "properties": {
                "routing_key": {"type": "string"},
                "rabbit_exchange": {"type": "string"},
            },
            "required": ["routing_key"],
            "additionalProperties": False,
        },
        defaultValue={"routing_key": "matcher", "rabbit_exchange": "luna.match"},
        description="Matcher queue settings.",
        services=["luna-admin", "luna-matcher"],
        groupNames=["luna-platform", "luna-queue"],
    )

    mh.addLimitation(
        limitationName="MATCHER_WORKER_AND_MESSAGE",
        validationSchema={
            "type": "object",
            "properties": {
                "msg": {"type": "object", "properties": {"path": {"type": "string"}}},
                "worker": {
                    "type": "object",
                    "properties": {
                        "connection": {
                            "type": "object",
                            "properties": {
                                "enableDLQ": {"type": "boolean"},
                                "qos": {"type": "integer"},
                                "disableAck": {"type": "boolean"},
                                "produceOnly": {"type": "boolean"},
                            },
                        }
                    },
                },
            },
            "description": "Worker and messaging settings.",
        },
        defaultValue={
            "msg": {"path": ""},
            "worker": {
                "connection": {
                    "enableDLQ": False,
                    "qos": 1,
                    "disableAck": False,
                    "produceOnly": False,
                }
            },
        },
        description="Matcher worker and messaging settings.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )

    mh.addLimitation(
        limitationName="MATCHING",
        validationSchema={
            "type": "object",
            "properties": {
                "cache": {
                    "type": "object",
                    "properties": {
                        "capacity": {"type": "integer"},
                        "policy": {"type": "string", "enum": ["classic", "warmup"]},
                        "skipList": {"type": "array", "items": {"type": "string"}},
                    },
                },
                "listsLoadExternalIds": {"type": "boolean"},
                "matcherStrategy": {
                    "type": "string",
                    "enum": ["lists", "indexes", "events"],
                },
                "staticBatchCapacity": {"type": "integer"},
                "staticBatchVersionCheckPeriod": {"type": "integer"},
                "matchingThreadCheckPeriodCoeff": {"type": "number"},
                "warmupPreloadPerPageRetries": {"type": "integer"},
                "lists_data_source": {"type": "string", "enum": ["rawfaces_api"]},
                "ef_search": {"type": "integer"},
                "goldengate_support": {"type": "boolean"},
                "onReload": {
                    "type": "object",
                    "properties": {
                        "logging": {
                            "type": "object",
                            "properties": {
                                "log-to-stderr": {"type": "boolean"},
                                "log-also-to-stderr": {"type": "boolean"},
                                "log-verbosity": {"type": "integer"},
                                "log-min-level": {"type": "integer"},
                                "log-buf-sec": {"type": "integer"},
                                "log-buf-level": {"type": "integer"},
                            },
                        }
                    },
                },
                "eventsInsertTimeDeltaHandicapSeconds": {
                    "type": "integer",
                    "minimum": 0,
                },
            },
            "description": "Matcher settings.",
        },
        defaultValue={
            "cache": {"capacity": 1500, "policy": "classic"},
            "matcherStrategy": "lists",
            "staticBatchCapacity": 5000,
            "staticBatchVersionCheckPeriod": 500,
            "matchingThreadCheckPeriodCoeff": 2.5,
            "warmupPreloadPerPageRetries": 5,
            "lists_data_source": "rawfaces_api",
            "goldengate_support": False,
            "onReload": {
                "logging": {
                    "log-to-stderr": False,
                    "log-also-to-stderr": True,
                    "log-verbosity": 2,
                    "log-min-level": 0,
                    "log-buf-sec": 30,
                    "log-buf-level": 0,
                }
            },
        },
        description="Matcher settings.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )
