"""
Configs migration

Generation datetime: 2021-08-12 10:38:02.528031
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper, LimitationToModify

mh: DatabaseMigrationHelper

REVISION = "95995b46"
DOWN_REVISION = "5b22225f"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="ATTRIBUTES_STORAGE_POLICY",
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-backport4", "luna-faces"],
        newServices=["luna-backport4", "luna-faces", "luna-handlers"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_LIMITS",
        validationSchema={
            "type": "object",
            "properties": {
                "received_images_limit": {"type": "integer", "minimum": 1},
                "raw_event_detections_limit": {"type": "integer", "minimum": 1},
                "raw_event_arrays_limit": {"type": "integer", "minimum": 1},
                "result_candidate_limit": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "received_images_limit": 8,
            "raw_event_detections_limit": 100,
            "raw_event_arrays_limit": 30,
            "result_candidate_limit": 100,
        },
        description="luna handlers limits",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_HANDLERS_LIMITS")
