"""
Configs migration

Generation datetime: 2021-10-29 15:48:17.975187
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper, LimitationToModify

mh: DatabaseMigrationHelper

REVISION = "b6da13a3"
DOWN_REVISION = "a7a66a42"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_BACKPORT3_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_backport3",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_backport3",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 5}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-backport3"],
        newServices=["luna-backport3"],
    ),
    LimitationToModify(
        limitationName="LUNA_HANDLERS_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_handlers",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_handlers",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 5}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
    LimitationToModify(
        limitationName="LUNA_INDEX_MANAGER_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_index_manager",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_index_manager",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 5}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-index-manager"],
        newServices=["luna-index-manager"],
    ),
    LimitationToModify(
        limitationName="LUNA_EVENTS_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "vertica",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_events",
            "db_host": "127.0.0.1",
            "db_port": 5433,
        },
        newDefaultValue={
            "db_type": "vertica",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_events",
            "db_host": "127.0.0.1",
            "db_port": 5433,
            "db_settings": {"connection_pool_size": 10},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 10}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-events", "luna-matcher-proxy", "luna-python-matcher"],
        newServices=["luna-events", "luna-matcher-proxy", "luna-python-matcher"],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_faces",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_faces",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 5}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-faces", "luna-matcher-proxy", "luna-python-matcher"],
        newServices=["luna-faces", "luna-matcher-proxy", "luna-python-matcher"],
    ),
    LimitationToModify(
        limitationName="LUNA_TASKS_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_tasks",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_tasks",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 5}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_ADMIN_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_admin",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_admin",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 1},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 1}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin"],
        newServices=["luna-admin"],
    ),
    LimitationToModify(
        limitationName="LUNA_CONFIGURATOR_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_configurator",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_configurator",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        settingUpgradeFunction=lambda setting: {**setting, "db_settings": {"connection_pool_size": 5}},
        settingDowngradeFunction=lambda setting: {k: v for k, v in setting.items() if k != "db_settings"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-configurator"],
        newServices=["luna-configurator"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
