"""
Configs migration

Generation datetime: 2023-03-20 08:09:51.585416
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper


PYTHON_SERVICES = [
    "luna-image-store",
    "luna-events",
    "luna-faces",
    "luna-api",
    "luna-admin",
    "luna-sender",
    "luna-tasks",
    "luna-configurator",
    "luna-handlers",
    "luna-python-matcher",
    "luna-matcher-proxy",
    "luna-licenses",
    "luna-backport4",
    "luna-backport3",
    "luna-accounts",
]

REVISION = "7105eb7e"
DOWN_REVISION = "d893870e"

limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName=f"{serviceName.replace('-', '_').upper()}_LOGGER",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json"]},
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
        },
        newDefaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        settingUpgradeFunction=lambda x: {**x, "format": "default"},
        settingDowngradeFunction=lambda x: {k: x[k] for k in x if k != "format"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[serviceName],
        newServices=[serviceName],
    )
    for serviceName in PYTHON_SERVICES
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
