"""
Configs migration

Generation datetime: 2024-08-15 12:28:49.643855
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "a6e4f71a"
DOWN_REVISION = "46b1afe4"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="ALLOW_LUNA_ACCOUNT_AUTH_HEADER",
        oldValidationSchema={"type": "boolean"},
        newValidationSchema={"type": "boolean"},
        oldDefaultValue=True,
        newDefaultValue=False,
        oldDescription="Whether to allow Luna-Account-Id auth header",
        newDescription="Whether to allow Luna-Account-Id auth header",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda oldValue: oldValue,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api"],
        newServices=["luna-api"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
