"""
Configs migration

Generation datetime: 2025-03-14 10:19:44.220921+00:00
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "11aa1d48"
DOWN_REVISION = "420c3721"


def upgradeSetting(setting: dict) -> dict:
    """Upgrade setting."""
    setting["tagging"] = True
    return setting


def downgradeSetting(setting: dict) -> dict:
    """Downgrade setting."""
    setting.pop("tagging", None)
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="S3",
        oldValidationSchema={
            "properties": {
                "host": {"type": "string"},
                "region": {"type": "string"},
                "aws_public_access_key": {"type": "string"},
                "aws_secret_access_key": {"type": "string"},
                "authorization_signature": {"type": "string", "enum": ["s3v2", "s3v4"]},
                "request_timeout": {"type": "integer"},
                "connect_timeout": {"type": "integer"},
                "verify_ssl": {"type": "boolean"},
            },
            "required": [
                "host",
                "aws_public_access_key",
                "aws_secret_access_key",
                "authorization_signature",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "host": {"type": "string"},
                "region": {"type": "string"},
                "aws_public_access_key": {"type": "string"},
                "aws_secret_access_key": {"type": "string"},
                "authorization_signature": {"type": "string", "enum": ["s3v2", "s3v4"]},
                "request_timeout": {"type": "integer"},
                "connect_timeout": {"type": "integer"},
                "verify_ssl": {"type": "boolean"},
                "tagging": {"type": "boolean"},
            },
            "required": [
                "host",
                "aws_public_access_key",
                "aws_secret_access_key",
                "authorization_signature",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "verify_ssl": True,
        },
        newDefaultValue={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "verify_ssl": True,
            "tagging": True,
        },
        settingUpgradeFunction=upgradeSetting,
        settingDowngradeFunction=downgradeSetting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-image-store"],
        newServices=["luna-image-store"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
