"""
Module contains settings class for configs. Mimics luna-configurator, because can be uses separately or together.
"""

from typing import Optional

from ..settings.classes import DBSetting as _DBSetting
from .base_python_service_settings import BasePythonServiceSettingsClass


class SettingsConfigs(BasePythonServiceSettingsClass):
    """
    Settings class for luna-configs
    Attributes:
        db(DBSetting): database settings
    """

    serviceName = "luna-configurator"

    def __init__(self):
        super().__init__()
        self.db: Optional[_DBSetting] = None

    def applySettings(self):
        """
        Deserialize loaded settings to classes
        """
        super().applySettings()
        self.db = _DBSetting(self.serviceName, self["LUNA_CONFIGURATOR_DB"])
